@@ -15,24 +15,19 @@ __pycache__/
 report/
 debug/"""
 
-
 client_content = """
+import json
+import time
 from mimetypes import MimeTypes
+from urllib.parse import urlencode
 
+import allure
 import jmespath
 import requests
-import json
-import allure
-from urllib.parse import urlencode
-import time
-
 from requests import Response
-
-from common.logger import Logger
-from common.config import *
 from requests_toolbelt.multipart.encoder import MultipartEncoder
-from until.fake import TepVars
 
+from aamt.config import *
 
 
 class Body_type():
@@ -52,7 +47,7 @@ class HttpClient(Body_type):
         self.session = requests.Session()
 
         # 变量池实例
-        self.aamt_vars = TepVars()
+        self.aamt_vars = AamtVars()
         # 日志实例
         self.logging = Logger
 
@@ -219,23 +214,19 @@ public_api_content = """
 # @Site:
 # @Time: 5月 05, 2022
 import sys
-from time import sleep
 
 import allure
 import jmespath
-from jsonpath import jsonpath
 
-from api.client import HttpClient
-from common.config import *
-from common.logger import Logger
+from aamt.client import HttpClient
+from aamt.config import *
+from aamt.logger import Logger
 from common.mysqlhelper import MysqlHelper
-from until.fake import fake
 
 sys.path.append("..")
 
 
 class Public(HttpClient):
-    # api = TepVars()
 
     def __init__(self, token):
         '''
@@ -245,7 +236,7 @@ class Public(HttpClient):
         # 从配置文件里 读取最新的token文件
         xin_token = Operate_config().read_token(section='Token', key=token)
         self.token = xin_token
-        print(f'读取到的最新token:{xin_token}')
+        Logger.warning(f'读取到的最新token:{xin_token}')
 
     @allure.step('新增全新公司：{name}')
     def add_company(self, name='xuefeng', cid=''):
@@ -267,6 +258,7 @@ class Public(HttpClient):
 
             url = self.get_full_url(url, h=self.host)
             ret = self.send(url=url, method=method, body=body, body_type=self.form_text, x_token=self.token)
+
             if jmespath.search('code', ret) == 200:
                 print('新增成功')
             elif jmespath.search('code', ret) == 500:
@@ -302,16 +294,17 @@ class Public(HttpClient):
             assert '存在' in ret['message'], f'异常, 新增公司模板 {name} 功能异常，请检查'
         else:
             assert False, f'异常，公司模板分配权限异常，接口响应信息；{ret}'
+
+
 """
 brand_controller_api_content = """
+
 # -*- coding: UTF-8 -*-
 import sys
 
 import jmespath
-
-# from common.config import *
 from api.brand.route import *
-from api.client import *
+from aamt.client import *
 
 sys.path.append("..")
 
@@ -383,7 +376,7 @@ class Brand_ControllerApi(HttpClient):
 
         if id:
 
-            # print(f'所有品牌列表：{list} \n取第一个品牌id:{id}')
+            # print(f'所有品牌列表：{list} 取第一个品牌id:{id}')
             url = brand_controller['del_brand']['url']
             method = brand_controller['del_brand']['method']
             body = {}
@@ -394,177 +387,76 @@ class Brand_ControllerApi(HttpClient):
         else:
 
             print(f'品牌：{brand_name} 不存在')
+
 """
 brand_route_content = """
-from common.config import *
+from aamt.config import *
 
 "后台品牌接口路径（前台）"
 brand_controller = Read_yaml().get_test_yaml(filepath="/brand/brand_controller.yaml")
 
 """
-conftest_content = """
-# -*- coding: UTF-8 -*-
-import sys
+fixture_admin_content = """
+# -*- coding: utf-8 -*-
+
+# @Software: PyCharm
+# @File: fixture_admin.py
+# @Author: xuefeng365
+# @E-mail: 120158568@qq.com,
+# @Site: www.51automate.cn
+# @Time: 11月 25, 2022
+
 
 import pytest
+from aamt.config import *
 
-from common.public_api import Public
-
-sys.path.append("..")
-
-from common.logintoken import Login_after
-
-# 导入token Environ env
-from common.config import *
-from common.public_api import get_authority_id
-
-
+# 管理员维护
 @pytest.fixture(scope='session')
 def env_vars_data():
-    result = Read_yaml().get_env_vars_yaml()
-    return result
+    return Read_yaml().get_env_vars_yaml()
+
+"""
+fixture_xf_content = """
+# -*- coding: utf-8 -*-
+
+# @Software: PyCharm
+# @File: fixture_xf.py
+# @Author: xuefeng365
+# @E-mail: 120158568@qq.com,
+# @Site: www.51automate.cn
+# @Time: 11月 25, 2022
+
+
+import pytest
+from aamt.logger import Logger
+
+from api.logintoken import Login_after
+from api.public_api import Public
 
 
-# --------------- 怡和 超级管理员管理后台 登录及其数据初始化 开始 -----------
 @pytest.fixture(scope="session")
-# def systerm_admin_login(user_info=env_vars_data['systerm']):
 def systerm_admin_login(env_vars_data):
-    print('超管登录')
     Login_after(env_vars_data['systerm'], 'systerm_admin_token')
 
 
-# @pytest.fixture(scope="session", autouse=True)
-@pytest.fixture(scope="session")
+# @pytest.fixture(scope="session", autouse=True)  # 自动运行
+@pytest.fixture(scope="session")  # 调用才运行
 def init_admin(systerm_admin_login):
-    # -------- 调用公共方法 新建基础数据（不需要返回值）  ---------
-    print('调用公共方法 新建基础数据（不需要返回值）')
+    Logger.info('调用公共方法 准备基础数据,返回一个实例')
     pub_d = Public(token='systerm_admin_token')
-    print('-+-+-+', env_vars_data['systerm'])
-
-    # 医生基础数据
-    warehouse_names = [f"{env_vars_data['systerm']['account']}仓库1", f"{env_vars_data['systerm']['account']}仓库2"]
-    warehouse_types = ['自有仓库', '店铺自有']
-    shelve_type1 = '入库区'
-    shelve_type2 = '出库区'
-    shelve_type3 = '普通区'
-
-    for warehouse_name in warehouse_names:
-        for warehouse_type in warehouse_types:
-            pub_d.add_warehouse(name=warehouse_name, type=warehouse_type)
-
-            pub_d.add_shelves(warehouse_name=warehouse_name, name=f'{warehouse_name}_{shelve_type1}', type=shelve_type1)
-            pub_d.add_shelves(warehouse_name=warehouse_name, name=f'{warehouse_name}_{shelve_type2}', type=shelve_type2)
-            pub_d.add_shelves(warehouse_name=warehouse_name, name=f'{warehouse_name}_{shelve_type3}', type=shelve_type3)
-
-    # 新增分类-已默认3个分类
-    pub_d.add_classification()
-
-    brand_name = 'auto品牌1'
-    commodity_upcs = [('111111229980', '主产品'), ('222222447863', '主产品'), ('888888861827', '非升级配件'),
-                      ('999999435729', '升级配件')]
-
-    # 新增品牌
-    pub_d.add_brand(name=brand_name)
-    # 新增upc
-    for commodity_upc in commodity_upcs:
-        pub_d.add_commodity(brand_name=brand_name, upcCode=commodity_upc[0], name='auto', types_name=commodity_upc[1])
-
-    template_role = ['auto_template', 'auto_role']
-    companys = [
-        ('怡和（不删）', ['521']),
-        ('xuefeng', ['5200', '5201']),
-        ('xuefeng2', ['5300', '5400'])
-    ]
-
-    # -------- 怡和 账号，新增公司、新增模板（分配全部权限）、新增角色（分配权限） 、新增用户（分配角色） ----------
-    for company in companys:
-        pub_d.add_company(name=company[0])
-
-    # 新增模板，给模板分配全部权限
-    resourceList = get_authority_id()
-    pub_d.company_template_assign_permissions(name=template_role[0], resourceList=resourceList)
-
-    # 公司分配模板
-    for company in companys:
-        if company != '怡和（不删）':
-            pub_d.assign_templates_to_companies(company_name=company[0], template_name=template_role[0])
-        else:
-            print('怡和主体 请自行分配模板，脚本跳过')
-
-    # 每个公司下 新建角色 并 给角色分配权限
-    for company in companys:
-        pub_d.add_role(company_name=company[0], role_name=template_role[1], cid=222260, resourses=resourceList)
-    # 每个公司下 新建用户 并 给用户分配权限
-    for company in companys:
-        for account in company[1]:
-            pub_d.add_user(company_name=company[0], account=account, password=account, firstName='脚本', lastName='新增',
-                           role_name=template_role[1])
-
-    # -------- 新增公司、新增模板（分配全部权限）、新增角色（分配权限） 、新增用户（分配角色） ----------
-
-    # # 给521分配仓库权限
-    # pub_d.assign_warehouse_permissions_to_users(account='521', warehouse_name='auto仓库')
-
-    # # ------------ 线下采购基础数据 -----------
-    # # 新增下线采购供应商 和 银行卡信息
-    # pub_d.add_Offline_purchasing_suppliers(suppliers='xuefeng线下采购')
-
     yield pub_d
 
 
-# --------------- 怡和 超级管理员管理后台 登录及其数据初始化 结束 -----------
-
-
 # --------------- xuefeng 医生1 登录及其数据初始化 开始 -----------
 @pytest.fixture(scope="session")
 def login_doctor1(env_vars_data):
-    print('xuefeng_doctor1 登录')
     Login_after(env_vars_data['xuefeng_doctor1'], 'xuefeng_doctor1_token')
 
 
-@pytest.fixture(scope="session", autouse=True)
-# @pytest.fixture(scope="session")
+@pytest.fixture(scope="session", autouse=True)  # 自动运行
+# @pytest.fixture(scope="session")  # 调用才运行
 def init_doctor1(login_doctor1):
-    # -------- 调用公共方法 新建基础数据（不需要返回值）  ---------
-    print('调用公共方法 新建基础数据（不需要返回值）')
     pub_d = Public(token='xuefeng_doctor1_token')
-    # 医生基础数据
-
-    warehouse_names = ['xuefeng_doctor1仓库1', 'xuefeng_doctor1仓库2']
-    warehouse_types = ['自有仓库', '店铺自有']
-    shelve_type1 = '入库区'
-    shelve_type2 = '出库区'
-    shelve_type3 = '普通区'
-
-    for warehouse_name in warehouse_names:
-        for warehouse_type in warehouse_types:
-            pub_d.add_warehouse(name=warehouse_name, type=warehouse_type)
-
-            pub_d.add_shelves(warehouse_name=warehouse_name, name=f'{warehouse_name}_{shelve_type1}', type=shelve_type1)
-            pub_d.add_shelves(warehouse_name=warehouse_name, name=f'{warehouse_name}_{shelve_type2}', type=shelve_type2)
-            pub_d.add_shelves(warehouse_name=warehouse_name, name=f'{warehouse_name}_{shelve_type3}', type=shelve_type3)
-
-    brand_name = 'auto品牌1'
-    commodity_upcs = [('111111229980', '主产品'), ('222222447863', '主产品'), ('888888861827', '非升级配件'),
-                      ('999999435729', '升级配件')]
-
-    skus = [('auto1_sku_00001', '全新', '111111229980'), ('auto1_sku_00002', '全新', '111111229980'),
-            ('auto1_sku_00003', '全新', '111111229980'),
-            ('auto2_sku_00001', '全新', '222222447863'), ('auto2_sku_00002', '全新', '222222447863'),
-            ('auto2_sku_00003', '全新', '222222447863'),
-            ('auto_sku_peijian_00001', '全新', '888888861827'),
-            ('auto_sku_peijian_shengji_00001', '全新', '999999435729')]
-
-    for commodity_upc in commodity_upcs:
-        pub_d.add_commodity(brand_name=brand_name, upcCode=commodity_upc[0], name='auto', types_name=commodity_upc[1])
-
-    for sku in skus:
-        pub_d.add_sku(skuCode=sku[0], newOld=sku[1], upcCode=sku[2], manager='52005200')
-
-    # # ------------ 线下采购基础数据 -----------
-    # # 新增下线采购供应商 和 银行卡信息
-    # pub_d.add_Offline_purchasing_suppliers(suppliers='xuefeng线下采购')
-
     yield pub_d
 
 
@@ -574,17 +466,13 @@ def init_doctor1(login_doctor1):
 # --------------- xuefeng 医生2 登录及其数据初始化 开始 -----------
 @pytest.fixture(scope="session")
 def login_doctor2(env_vars_data):
-    print('xuefeng_doctor2 登录')
     Login_after(env_vars_data['xuefeng_doctor2'], 'xuefeng_doctor2_token')
 
 
-# @pytest.fixture(scope="session", autouse=True)
-@pytest.fixture(scope="session")
+# @pytest.fixture(scope="session", autouse=True)  # 自动运行
+@pytest.fixture(scope="session")  # 调用才运行
 def init_doctor2(login_doctor2):
-    # -------- 调用公共方法 新建基础数据（不需要返回值）  ---------
-    print('调用公共方法 新建基础数据（不需要返回值）')
     pub_d = Public(token='xuefeng_doctor2_token')
-
     yield pub_d
 
 
@@ -598,32 +486,10 @@ def login_nurse1(env_vars_data):
     Login_after(env_vars_data['xuefeng2_nurse1'], 'xuefeng2_nurse1_token')
 
 
-# 返回值-护士身份- 增加基础数据 返回公共方法实例
 # @pytest.fixture(scope="session", autouse=True)
 @pytest.fixture(scope="session")
 def init_nurse1(login_nurse1):
-    # -------- 调用公共方法 新建基础数据（不需要返回值）  ---------
-    print('调用公共方法 新建基础数据（不需要返回值）')
     pub_n = Public(token='xuefeng2_nurse1_token')
-
-    # # 护士基础数据
-    # pub_n.add_warehouse(name='auto护士仓库', type='护士仓库')
-    #
-    # pub_n.add_shelves(warehouse_name='auto护士仓库',name='auto护士入库区1', type='入库区')
-    # pub_n.add_shelves(warehouse_name='auto护士仓库',name='auto护士出库区1', type='出库区')
-    # pub_n.add_shelves(warehouse_name='auto护士仓库',name='auto护士破损区1', type='破损区')
-    #
-    # # 给5201分配仓库权限
-    # pub_n.assign_warehouse_permissions_to_users(account='5201', warehouse_name='auto护士仓库')
-    #
-    #
-    # # 期货护士绑定采购商
-    # pub_n.bind_buyers(codeOrName=pub_n.get_company_cid(company_name='怡和（不删）'))
-    # # 期货护士添加支付方式--如果有自动化新增的支付方式，就跳过
-    # pub_n.nurse_add_payment_method()
-    # # 现货--个人中心新增一个地址
-    # pub_n.center_self_add_address()
-
     yield pub_n
 
 
@@ -637,37 +503,32 @@ def login_nurse2(env_vars_data):
     Login_after(env_vars_data['xuefeng2_nurse2'], 'xuefeng2_nurse2_token')
 
 
-# 返回值-护士身份- 增加基础数据 返回公共方法实例
 # @pytest.fixture(scope="session", autouse=True)
 @pytest.fixture(scope="session")
 def init_nurse2(login_nurse2):
-    # -------- 调用公共方法 新建基础数据（不需要返回值）  ---------
-    print('调用公共方法 新建基础数据（不需要返回值）')
     pub_n = Public(token='xuefeng2_nurse2_token')
-
     yield pub_n
 
-
 # --------------- xuefeng2 护士2 登录及其数据初始化 结束 -----------
 
+"""
+conftest_content = """
+# -*- coding: utf-8 -*-
 
-# --------------- guangzhou 医生1 登录及其数据初始化 开始 -----------
+# @Software: PyCharm
+# @File: conftest.py
+# @Author: xuefeng365
+# @E-mail: 120158568@qq.com,
+# @Site: www.51automate.cn
+# @Time: 11月 25, 2022
 
-@pytest.fixture(scope="session")
-def login_doctor1_gz(env_vars_data):
-    Login_after(env_vars_data['gz_doctor1'], 'gz_doctor1_token')
+# import sys
+# sys.path.append("..")
 
+from aamt.plugin import aamt_plugins
 
-# @pytest.fixture(scope="session", autouse=True)
-@pytest.fixture(scope="session")
-def init_d(login_doctor1_gz):
-    # -------- 调用公共方法 新建基础数据（不需要返回值）  ---------
-    print('调用公共方法 新建基础数据（不需要返回值）')
-    pub_d = Public(token='gz_doctor1_token')
-
-    yield pub_d
-
-# --------------- guangzhou 医生1 登录及其数据初始化 结束 -----------
+# 加载aamt插件
+pytest_plugins = aamt_plugins()
 
 
 """
@@ -777,15 +638,26 @@ def assert_api(actual_data,expect_data):
 """
 config_content = """
 # -*- coding: UTF-8 -*-
+# @Software: PyCharm
+# @File: config.py
+# @Author: xuefeng365
+# @E-mail: 120158568@qq.com,
+# @Site:
+# @Time: 11月 23, 2022
+
+
 import configparser
 import os
 
 import yaml
 
+from aamt.logger import Logger
+
 
 class Config():
     # 全局项目根目录
-    project_root_dir = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
+    project_root_dir = ''
+    # project_root_dir = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
 
 
 class Operate_config(Config):
@@ -824,7 +696,6 @@ class Read_yaml(Operate_config):
     def get_env_vars_yaml(self):
         env_active = self.read_environ_active()
         env_filename = f'env_vars_{env_active}.yaml'
-
         with open(
                 os.path.join(self.project_root_dir, "resources", "env_vars", env_filename), encoding="utf-8") as f:
             return yaml.load(f.read(), Loader=yaml.FullLoader)
@@ -834,7 +705,7 @@ class Read_yaml(Operate_config):
         filepath="/brand/brand_controller.yaml"
         '''
         # 测试用例数据
-        test_data_path = f"{Config.project_root_dir}/data/{filepath}".replace("\\\\", "/").replace("//", "/")
+        test_data_path = f"{Config.project_root_dir}/data/{filepath}".replace("\\", "/").replace("//", "/")
 
         with open(test_data_path, encoding="utf-8") as f:
             return yaml.load(f.read(), Loader=yaml.FullLoader)
@@ -845,10 +716,49 @@ def get_file_path(file_name, middle='file'):
     file_name: 文件名，比如 xiaoxin.png
     '''
 
-    filePath = f"{Config.project_root_dir}/{middle}/{file_name}".replace("\\\\", "/").replace("//", "/")
+    filePath = f"{Config.project_root_dir}/{middle}/{file_name}".replace("\\", "/").replace("//", "/")
     return filePath
 
 
+def fixture_paths(root_path=Config.project_root_dir):
+    '''
+    fixture路径，1、项目下的fixtures；2、aamt下的fixture；
+    :return:
+    '''
+    _fixtures_dir = os.path.join(root_path, "fixtures")
+    paths = []
+    # 项目下的fixtures
+    for root, _, files in os.walk(_fixtures_dir):
+        for file in files:
+            if file.startswith("fixture_") and file.endswith(".py"):
+                full_path = os.path.join(root, file)
+                import_path = full_path.replace(_fixtures_dir, "").replace("\\", ".")
+                import_path = import_path.replace("/", ".").replace(".py", "")
+                paths.append("fixtures" + import_path)
+    # aamt下的fixture
+    paths.append("aamt.fixture")
+    return paths
+
+
+class AamtVars:
+    # 全局变量池
+
+    def __init__(self):
+        self.vars_ = {'a': '初始值'}
+
+    def put(self, key, value):
+        self.vars_[key] = value
+        Logger.info(f'变量池 成功新增：{{{key}：{value}}}')
+
+    def get(self, key):
+        value = ""
+        try:
+            value = self.vars_[key]
+        except KeyError:
+            Logger.error(f'异常：获取 {key} 失败, 当前变量池：{self.vars_}')
+        return value
+
+
 # 获取配置文件中的key值 (token值)
 systerm_admin_token = Operate_config().read_token(key='systerm_admin_token')
 xuefeng2_doctor1_token = Operate_config().read_token(key='xuefeng_doctor1_token')
@@ -978,54 +888,22 @@ if __name__ == '__main__':
 logintoken_content = """
 # -*- coding: utf-8 -*-
 
+
 import hashlib
 
 import jmespath
-
-from api.client import HttpClient
-from common.config import *
+from aamt.client import HttpClient
+from aamt.config import *
+from aamt.logger import Logger
 
 
-# ***********  前端登录  ***********
-
-class Login(HttpClient):
-    ''' 初始化登录-- 定义token（coolie 或者 session）字段：目的为了鉴权，并将其写入配置文件'''
-
-    def __init__(self, user_info, token):
-        super().__init__()  # 继承上个类的ini
-        self.username = user_info['userEmail']
-        self.password = user_info['userPassword']
-        result = self.login_front(username=self.username, password=self.password)
-        assert result['code'] == 200, "前台登录失败"
-        self.token = result['result']['token']
-        print(f'======自动运行：先获取 前台{token}========: {self.token}')
-
-        # 把token值写入配置文件中
-        Operate_config().write(section="Token", key=token, value=self.token)
-
-    def login_front(self, username, password):
-        body = {
-            "userEmail": username,
-            "userPassword": password
-        }
-        url = '/internet/user/login'
-        method = 'post'
-        url = super().get_full_url(url, h=self.env_vars_data['front_host'])
-        return super().send(url=url, method=method, body=body, body_type=self.json)
-
-
-# **********************************
-
-
-# ***********  后台登录  ***********
-
+# ***********  后台登录开始  ***********
 class Login_after(HttpClient):
 
     def __init__(self, user_info, token):
         # 传入token（coolie 或者 session）字段：目的为了写入配置文件
         super().__init__()  # 继承上个类的ini
         self.username = user_info['account']
-
         # ----------- 密码进行MD5加密 ------------ #
         mima = str(user_info['password'])
         # md5加密对象
@@ -1034,15 +912,12 @@ class Login_after(HttpClient):
         md5.update(mima.encode('utf-8'))
         # 转化为16进制字符串
         new_mima = md5.hexdigest()
-
         # ----------- MD5加密结束 ------------ #
-
         self.password = new_mima
-
         result = self.login_after(username=self.username, password=self.password)
         assert jmespath.search('code', result) == 200, f"系统管理登录失败,接口响应 \n {result}\n"
         self.token = result['result']['token']
-        print(f'======自动运行：先获取 后台token========: {self.token}')
+        Logger.info(f'账号：{self.username} 登录成功，新token：{self.token}')
         # 把token值写入配置文件中
         Operate_config().write(section="Token", key=token, value=self.token)
 
@@ -1053,10 +928,17 @@ class Login_after(HttpClient):
         }
         url = '/system/userInfo/login'
         method = 'get'
-        url = super().get_full_url(url, etc=etc, h=self.env_vars_data['after_host'])
-        return super().send(url=url, method=method)
+        url = self.get_full_url(url, etc=etc, h=self.env_vars_data['after_host'])
+        return self.send(method=method, url=url)
+
+# ***********  后台登录结束  ***********
+
+
+# ***********  前端登录开始  ***********
+# XXXXXXXX 支持扩展 XXXXXXXXX
+# ***********  前端登录结束  *************
+
 
-# ***********************************
 
 """
 mysqlhelper_content = """
@@ -1628,25 +1510,6 @@ class Faker_:
         return self.fake.md5()
 
 
-class TepVars:
-    # 全局变量池
-
-    def __init__(self):
-        self.vars_ = {'a': '初始值'}
-
-    def put(self, key, value):
-        self.vars_[key] = value
-        Logger.info(f'变量池 成功新增：{{{key}：{value}}}')
-
-    def get(self, key):
-        value = ""
-        try:
-            value = self.vars_[key]
-        except KeyError:
-            Logger.error(f'异常：获取 {key} 失败, 当前变量池：{self.vars_}')
-        return value
-
-
 if __name__ == "__main__":
     test = Faker_()
     print(test.get_name())
@@ -1792,8 +1655,31 @@ urllib3==1.26.12
 win32-setctime==1.1.0
 
 """
-Markdown_content = """
-# 待补充
+README_content = """
+安装最新版本
+
+> pip install aamt
+
+指定版本安装
+
+> pip install tep==0.1.0
+
+升级aamt
+
+> pip install -U aamt
+
+创建项目脚手架 
+
+> aamt startproject demo
+
+创建项目脚手架(自动创建虚拟环境)
+
+> aamt startproject demo -venv
+
+外网速度慢，pandas可能安装失败，推荐用国内镜像
+
+> pip --default-timeout=6000 install -i https://pypi.tuna.tsinghua.edu.cn/simple aamt
+
 """
 
 fastapi_mock_content = """#!/usr/bin/python
@@ -1869,7 +1755,7 @@ filename = f'test_{time.strftime("%Y%m%d_%H%M%S", time.localtime())}.py'
 case_file = os.path.join(mitm_dir, filename)
 # 生成用例文件
 template = \"\"\"import allure
-from tep.client import request
+from aamt.client import request
 
 
 @allure.title("")
@@ -1954,25 +1840,5 @@ mitmdump -s mitm.py --mode reverse:http://127.0.0.1:5000 --listen-host 127.0.0.1
 """
 
 structure_content = """项目结构说明：
-files：文件
-fixtures：pytest fixture
-reports：allure测试报告
-samples：示例代码
-  db：数据库
-    test_mysql.py：连接MySQL
-  http：requests请求
-    test_request.py：requests常见用法
-    test_request_monkey_patch.py：tep request猴子补丁测试
-  login_pay：登陆到下单流程
-    mvc：mvc接口用例分离示例（不推荐）
-    tep：极速写法（强烈推荐）
-tests：测试用例
-utils：工具
-  fastapi_mock.py：自带fastapi项目
-  http_client.py：tep request猴子补丁
-  mitm.py：mitmproxy抓包自动生成用例
-.gitignore：Git忽略文件规则
-conf.yaml：项目配置
-conftest.py：pytest conftest
-pytest.ini：pytest配置
+待完善
 """
